@@ -27,9 +27,6 @@
 
 extern ZEND_DECLARE_MODULE_GLOBALS(xdebug);
 
-static void xdebug_build_fname_from_oparray(xdebug_func *tmp, zend_op_array *opa TSRMLS_DC);
-static char* xdebug_func_format(xdebug_func *func TSRMLS_DC);
-
 void xdebug_coverage_line_dtor(void *data)
 {
 	xdebug_coverage_line *line = (xdebug_coverage_line *) data;
@@ -483,7 +480,7 @@ XDEBUG_OPCODE_OVERRIDE_ASSIGN(assign_bw_xor,"^=",0)
 XDEBUG_OPCODE_OVERRIDE_ASSIGN(assign_dim,"=",1)
 XDEBUG_OPCODE_OVERRIDE_ASSIGN(assign_obj,"=",1)
 
-inline void xdebug_count_line(char *filename, int lineno, int executable, int deadcode TSRMLS_DC)
+void xdebug_count_line(char *filename, int lineno, int executable, int deadcode TSRMLS_DC)
 {
 	xdebug_coverage_file *file;
 	xdebug_coverage_line *line;
@@ -534,6 +531,12 @@ static void prefill_from_opcode(char *fn, zend_op opcode, int deadcode TSRMLS_DC
 		&& opcode.opcode != ZEND_OP_DATA
 		&& opcode.opcode != ZEND_ADD_INTERFACE
 		&& opcode.opcode != ZEND_TICKS
+#if PHP_VERSION_ID >= 50500
+		&& opcode.opcode != ZEND_FAST_CALL
+#endif
+#if PHP_VERSION_ID >= 50600
+		&& opcode.opcode != ZEND_RECV_VARIADIC
+#endif
 	) {
 		xdebug_count_line(fn, opcode.lineno, 1, deadcode TSRMLS_CC);
 	}
@@ -592,11 +595,12 @@ static int xdebug_find_jump(zend_op_array *opa, unsigned int position, long *jmp
 		return 1;
 	} else if (opcode.opcode == ZEND_JMPZNZ) {
 #if PHP_VERSION_ID >= 70000
-		*jmp1 = XDEBUG_ZNODE_JMP_LINE(opcode.op2, position, base_address) * sizeof(zend_op);
+		*jmp1 = XDEBUG_ZNODE_JMP_LINE(opcode.op2, position, base_address);
+		*jmp2 = (int32_t) (position + ((int32_t)opcode.extended_value / sizeof(zend_op)));
 #else
 		*jmp1 = XDEBUG_ZNODE_ELEM(opcode.op2, opline_num);
-#endif
 		*jmp2 = opcode.extended_value;
+#endif
 		return 1;
 #if PHP_VERSION_ID < 70000
 	} else if (opcode.opcode == ZEND_BRK || opcode.opcode == ZEND_CONT) {
@@ -663,15 +667,10 @@ static int xdebug_find_jump(zend_op_array *opa, unsigned int position, long *jmp
 #else
 		*jmp1 = ((long) XDEBUG_ZNODE_ELEM(opcode.op1, jmp_addr) - (long) base_address) / sizeof(zend_op);
 #endif
-		if (opcode.extended_value) {
-			*jmp2 = XDEBUG_ZNODE_ELEM(opcode.op2, opline_num);
-		}
+		*jmp2 = position + 1;
 		return 1;
 	} else if (opcode.opcode == ZEND_FAST_RET) {
-		*jmp1 = position + 1;
-		if (opcode.extended_value) {
-			*jmp2 = XDEBUG_ZNODE_ELEM(opcode.op2, opline_num);
-		}
+		*jmp1 = XDEBUG_JMP_EXIT;
 		return 1;
 #endif
 
@@ -802,7 +801,7 @@ static void xdebug_analyse_oparray(zend_op_array *opa, xdebug_set *set, xdebug_b
 	}
 }
 
-static void xdebug_build_fname_from_oparray(xdebug_func *tmp, zend_op_array *opa TSRMLS_DC)
+void xdebug_build_fname_from_oparray(xdebug_func *tmp, zend_op_array *opa TSRMLS_DC)
 {
 	int closure = 0;
 
@@ -832,7 +831,7 @@ static void xdebug_build_fname_from_oparray(xdebug_func *tmp, zend_op_array *opa
 	}
 }
 
-static char* xdebug_func_format(xdebug_func *func TSRMLS_DC)
+char* xdebug_func_format(xdebug_func *func TSRMLS_DC)
 {
 	switch (func->type) {
 		case XFUNC_NORMAL:
@@ -961,7 +960,7 @@ void xdebug_prefill_code_coverage(zend_op_array *op_array TSRMLS_DC)
 	zend_hash_apply_with_arguments(CG(class_table) TSRMLS_CC, (apply_func_args_t) prefill_from_class_table, 1, STR_NAME_VAL(op_array->filename));
 }
 
-void xdebug_code_coverage_start_of_function(zend_op_array *op_array TSRMLS_DC)
+void xdebug_code_coverage_start_of_function(zend_op_array *op_array, char *function_name TSRMLS_DC)
 {
 	xdebug_path *path = xdebug_path_new(NULL);
 
@@ -976,13 +975,10 @@ void xdebug_code_coverage_start_of_function(zend_op_array *op_array TSRMLS_DC)
 	XG(branches).last_branch_nr[XG(level)] = -1;
 }
 
-void xdebug_code_coverage_end_of_function(zend_op_array *op_array TSRMLS_DC)
+void xdebug_code_coverage_end_of_function(zend_op_array *op_array, char *file_name, char *function_name TSRMLS_DC)
 {
 	xdebug_str str = XDEBUG_STR_INITIALIZER;
 	xdebug_path *path = xdebug_path_info_get_path_for_level(XG(paths_stack), XG(level) TSRMLS_CC);
-	char *file = (char*) STR_NAME_VAL(op_array->filename);
-	xdebug_func func_info;
-	char *function_name;
 
 	if (!path) {
 		return;
@@ -990,19 +986,8 @@ void xdebug_code_coverage_end_of_function(zend_op_array *op_array TSRMLS_DC)
 
 	xdebug_create_key_for_path(path, &str);
 
-	xdebug_build_fname_from_oparray(&func_info, op_array TSRMLS_CC);
-	function_name = xdebug_func_format(&func_info TSRMLS_CC);
+	xdebug_branch_info_mark_end_of_function_reached(file_name, function_name, str.d, str.l TSRMLS_CC);
 
-	if (func_info.class) {
-		xdfree(func_info.class);
-	}
-	if (func_info.function) {
-		xdfree(func_info.function);
-	}
-
-	xdebug_branch_info_mark_end_of_function_reached(file, function_name, str.d, str.l TSRMLS_CC);
-
-	xdfree(function_name);
 	xdfree(str.d);
 
 	if (path) {
