@@ -55,11 +55,14 @@ void xdebug_coverage_line_dtor(void *data);
 xdebug_coverage_file *xdebug_coverage_file_ctor(char *filename);
 void xdebug_coverage_file_dtor(void *data);
 
+char* xdebug_func_format(xdebug_func *func TSRMLS_DC);
+void xdebug_build_fname_from_oparray(xdebug_func *tmp, zend_op_array *opa TSRMLS_DC);
+
 xdebug_coverage_function *xdebug_coverage_function_ctor(char *function_name);
 void xdebug_coverage_function_dtor(void *data);
 void xdebug_print_opcode_info(char type, zend_execute_data *execute_data, const zend_op *cur_opcode TSRMLS_DC);
-void xdebug_code_coverage_start_of_function(zend_op_array *op_array TSRMLS_DC);
-void xdebug_code_coverage_end_of_function(zend_op_array *op_array TSRMLS_DC);
+void xdebug_code_coverage_start_of_function(zend_op_array *op_array, char *function_name TSRMLS_DC);
+void xdebug_code_coverage_end_of_function(zend_op_array *op_array, char *file_name, char *function_name TSRMLS_DC);
 
 int xdebug_check_branch_entry_handler(ZEND_USER_OPCODE_HANDLER_ARGS);
 int xdebug_common_override_handler(ZEND_USER_OPCODE_HANDLER_ARGS);
