@@ -63,6 +63,8 @@ typedef struct xdebug_var {
 #define XFUNC_REQUIRE        0x13
 #define XFUNC_REQUIRE_ONCE   0x14
 
+#define XFUNC_ZEND_PASS      0x20
+
 #define XDEBUG_IS_FUNCTION(f) (f == XFUNC_NORMAL || f == XFUNC_STATIC_MEMBER || f == XFUNC_MEMBER)
 
 #define XDEBUG_REGISTER_LONG_CONSTANT(__c) REGISTER_LONG_CONSTANT(#__c, __c, CONST_CS|CONST_PERSISTENT)
@@ -194,10 +196,11 @@ typedef struct _function_stack_entry {
 
 	/* profiling properties */
 	xdebug_profile profile;
-#if 0
-	double       time_taken;	
-	unsigned int f_calls;
-#endif
+	struct {
+		int   lineno;
+		char *filename;
+		char *funcname;
+	} profiler;
 
 	/* misc properties */
 	int          refcount;
