@@ -35,6 +35,18 @@
 #include "xdebug_var.h"
 #include "xdebug_xml.h"
 
+/* Set correct int format to use */
+#if PHP_VERSION_ID >= 70000
+# include "Zend/zend_long.h"
+# if SIZEOF_ZEND_LONG == 4
+#  define XDEBUG_INT_FMT "%ld"
+# else
+#  define XDEBUG_INT_FMT "%lld"
+# endif
+#else
+# define XDEBUG_INT_FMT "%ld"
+#endif
+
 ZEND_EXTERN_MODULE_GLOBALS(xdebug)
 
 HashTable *xdebug_objdebug_pp(zval **zval_pp, int *is_tmp TSRMLS_DC)
@@ -44,11 +56,22 @@ HashTable *xdebug_objdebug_pp(zval **zval_pp, int *is_tmp TSRMLS_DC)
 
 	if (!XG(in_debug_info) && Z_OBJ_HANDLER(dzval, get_debug_info)) {
 		zend_bool old_trace = XG(do_trace);
+#if PHP_VERSION_ID >= 70000
+		zend_object *orig_exception;
+#else
+		zval *orig_exception;
+#endif
+
 		XG(do_trace) = 0;
 		XG(in_debug_info) = 1;
+		orig_exception = EG(exception);
+		EG(exception) = NULL;
+
 		tmp = Z_OBJ_HANDLER(dzval, get_debug_info)(&dzval, is_tmp TSRMLS_CC);
+
 		XG(in_debug_info) = 0;
 		XG(do_trace) = old_trace;
+		EG(exception) = orig_exception;
 		return tmp;
 	} else {
 		*is_tmp = 0;
@@ -908,7 +931,7 @@ static int xdebug_array_element_export(zval **zv TSRMLS_DC, int num_args, va_lis
 		options->runtime[level].current_element_nr < options->runtime[level].end_element_nr)
 	{
 		if (HASH_KEY_IS_NUMERIC(hash_key)) { /* numeric key */
-			xdebug_str_add(str, xdebug_sprintf("%ld => ", HASH_APPLY_NUMERIC(hash_key)), 1);
+			xdebug_str_add(str, xdebug_sprintf(XDEBUG_INT_FMT " => ", HASH_APPLY_NUMERIC(hash_key)), 1);
 		} else { /* string key */
 			SIZETorINT newlen = 0;
 			char *tmp, *tmp2;
@@ -1028,7 +1051,7 @@ void xdebug_var_export(zval **struc, xdebug_str *str, int level, int debug_zval,
 			break;
 
 		case IS_LONG:
-			xdebug_str_add(str, xdebug_sprintf("%ld", Z_LVAL_P(*struc)), 1);
+			xdebug_str_add(str, xdebug_sprintf(XDEBUG_INT_FMT, Z_LVAL_P(*struc)), 1);
 			break;
 
 		case IS_DOUBLE:
@@ -1331,7 +1354,7 @@ static int xdebug_array_element_export_text_ansi(zval **zv TSRMLS_DC, int num_ar
 		xdebug_str_add(str, xdebug_sprintf("%*s", (level * 2), ""), 1);
 
 		if (HASH_KEY_IS_NUMERIC(hash_key)) { /* numeric key */
-			xdebug_str_add(str, xdebug_sprintf("[%ld] %s=>%s\n", HASH_APPLY_NUMERIC(hash_key), ANSI_COLOR_POINTER, ANSI_COLOR_RESET), 1);
+			xdebug_str_add(str, xdebug_sprintf("[" XDEBUG_INT_FMT "] %s=>%s\n", HASH_APPLY_NUMERIC(hash_key), ANSI_COLOR_POINTER, ANSI_COLOR_RESET), 1);
 		} else { /* string key */
 			SIZETorINT newlen = 0;
 			char *tmp, *tmp2;
@@ -1453,7 +1476,7 @@ void xdebug_var_export_text_ansi(zval **struc, xdebug_str *str, int mode, int le
 			break;
 
 		case IS_LONG:
-			xdebug_str_add(str, xdebug_sprintf("%sint%s(%s%ld%s)", ANSI_COLOR_BOLD, ANSI_COLOR_BOLD_OFF, ANSI_COLOR_LONG, Z_LVAL_P(*struc), ANSI_COLOR_RESET), 1);
+			xdebug_str_add(str, xdebug_sprintf("%sint%s(%s" XDEBUG_INT_FMT "%s)", ANSI_COLOR_BOLD, ANSI_COLOR_BOLD_OFF, ANSI_COLOR_LONG, Z_LVAL_P(*struc), ANSI_COLOR_RESET), 1);
 			break;
 
 		case IS_DOUBLE:
@@ -1766,7 +1789,7 @@ static int object_item_add_to_merged_hash(zval **zv TSRMLS_DC, int num_args, va_
 		item->name_len = HASH_APPLY_KEY_LEN(hash_key) - 1;
 		item->index = hash_key->h;
 	} else {
-		item->name = xdebug_sprintf("%ld", index);
+		item->name = xdebug_sprintf(XDEBUG_INT_FMT, index);
 		item->name_len = strlen(item->name);
 	}
 #else
@@ -1869,7 +1892,7 @@ static int xdebug_array_element_export_xml_node(zval **zv TSRMLS_DC, int num_arg
 				xdebug_str_addl(&full_name, "']", 2, 0);
 			}
 		} else {
-			name = xdebug_sprintf("%ld", HASH_APPLY_NUMERIC(hash_key));
+			name = xdebug_sprintf(XDEBUG_INT_FMT, HASH_APPLY_NUMERIC(hash_key));
 			name_len = strlen(name);
 			if (parent_name) {
 				xdebug_str_add(&full_name, xdebug_sprintf("%s[%s]", parent_name, name), 1);
@@ -1940,10 +1963,10 @@ static int xdebug_object_element_export_xml_node(xdebug_object_item **item TSRML
 		} else { /* Numerical property name */
 			modifier = "public";
 
-			xdebug_xml_add_attribute_ex(node, "name", xdebug_sprintf("%ld", (*item)->index), 0, 1);
+			xdebug_xml_add_attribute_ex(node, "name", xdebug_sprintf(XDEBUG_INT_FMT, (*item)->index), 0, 1);
 
 			if (parent_name) {
-				full_name = xdebug_sprintf("%s%s%ld", parent_name, (*item)->type == XDEBUG_OBJECT_ITEM_TYPE_STATIC_PROPERTY ? "::" : "->", (*item)->index);
+				full_name = xdebug_sprintf("%s%s" XDEBUG_INT_FMT, parent_name, (*item)->type == XDEBUG_OBJECT_ITEM_TYPE_STATIC_PROPERTY ? "::" : "->", (*item)->index);
 				xdebug_xml_add_attribute_ex(node, "fullname", full_name, 0, 1);
 			}
 		}
@@ -2107,7 +2130,7 @@ void xdebug_var_export_xml_node(zval **struc, char *name, xdebug_xml_node *node,
 
 		case IS_LONG:
 			xdebug_xml_add_attribute(node, "type", "int");
-			xdebug_xml_add_text(node, xdebug_sprintf("%ld", Z_LVAL_P(*struc)));
+			xdebug_xml_add_text(node, xdebug_sprintf(XDEBUG_INT_FMT, Z_LVAL_P(*struc)));
 			break;
 
 		case IS_DOUBLE:
@@ -2335,7 +2358,7 @@ static int xdebug_array_element_export_fancy(zval **zv TSRMLS_DC, int num_args,
 		xdebug_str_add(str, xdebug_sprintf("%*s", (level * 4) - 2, ""), 1);
 
 		if (HASH_KEY_IS_NUMERIC(hash_key)) { /* numeric key */
-			xdebug_str_add(str, xdebug_sprintf("%ld <font color='%s'>=&gt;</font> ", HASH_APPLY_NUMERIC(hash_key), COLOR_POINTER), 1);
+			xdebug_str_add(str, xdebug_sprintf(XDEBUG_INT_FMT " <font color='%s'>=&gt;</font> ", HASH_APPLY_NUMERIC(hash_key), COLOR_POINTER), 1);
 		} else { /* string key */
 			xdebug_str_addl(str, "'", 1, 0);
 			tmp_str = xdebug_xmlize((char*) HASH_APPLY_KEY_VAL(hash_key), HASH_APPLY_KEY_LEN(hash_key) - 1, &newlen);
@@ -2445,7 +2468,7 @@ void xdebug_var_export_fancy(zval **struc, xdebug_str *str, int level, int debug
 			break;
 
 		case IS_LONG:
-			xdebug_str_add(str, xdebug_sprintf("<small>int</small> <font color='%s'>%ld</font>", COLOR_LONG, Z_LVAL_P(*struc)), 1);
+			xdebug_str_add(str, xdebug_sprintf("<small>int</small> <font color='%s'>" XDEBUG_INT_FMT "</font>", COLOR_LONG, Z_LVAL_P(*struc)), 1);
 			break;
 
 		case IS_DOUBLE:
@@ -2878,6 +2901,10 @@ char* xdebug_show_fname(xdebug_func f, int html, int flags TSRMLS_DC)
 			return xdstrdup("require_once");
 			break;
 
+		case XFUNC_ZEND_PASS:
+			return xdstrdup("{zend_pass}");
+			break;
+
 		default:
 			return xdstrdup("{unknown}");
 	}
